.. filefisher documentation master file, created by
   sphinx-quickstart on Fri Dec 20 18:22:59 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: ../../README.md
   :parser: myst_parser.sphinx_


.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: For Users

   installation
   usage

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: API Reference

   api

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Versions

   changelog
